<!--

@license Apache-2.0

Copyright (c) 2022 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# FLOAT32_SIGNIFICAND_MASK

> Mask for the significand of a [single-precision floating-point number][ieee754].

<section class="usage">

## Usage

<!-- eslint-disable id-length -->

```javascript
var FLOAT32_SIGNIFICAND_MASK = require( '@stdlib/constants/float32/significand-mask' );
```

#### FLOAT32_SIGNIFICAND_MASK

Mask for the significand of a [single-precision floating-point number][ieee754].

<!-- eslint-disable id-length -->

```javascript
// 0x007fffff = 8388607 => 0 00000000 11111111111111111111111
var bool = ( FLOAT32_SIGNIFICAND_MASK === 0x007fffff );
// returns true
```

</section>

<!-- /.usage -->

<section class="notes">

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var toWord = require( '@stdlib/number/float32/base/to-word' );
var FLOAT32_SIGNIFICAND_MASK = require( '@stdlib/constants/float32/significand-mask' );

var x = 11.5;
var w = toWord( x ); // 0 10000010 01110000000000000000000
// returns 1094189056

// Mask off all bits except for the significand bits:
var out = w & FLOAT32_SIGNIFICAND_MASK; // 0 00000000 01110000000000000000000
// returns 3670016

// Mask on the significand bits and leave other bits unchanged:
out = w | FLOAT32_SIGNIFICAND_MASK; // 0 10000010 11111111111111111111111
// returns 1098907647
```

</section>

<!-- /.examples -->

<!-- C interface documentation. -->

* * *

<section class="c">

## C APIs

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- C usage documentation. -->

<section class="usage">

### Usage

```c
#include "stdlib/constants/float32/significand_mask.h"
```

#### STDLIB_CONSTANT_FLOAT32_SIGNIFICAND_MASK

Macro for the mask for the significand of a [single-precision floating-point number][ieee754].

</section>

<!-- /.usage -->

<!-- C API usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<!-- C API usage examples. -->

<section class="examples">

</section>

<!-- /.examples -->

</section>

<!-- /.c -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[ieee754]: https://en.wikipedia.org/wiki/IEEE_754-1985

</section>

<!-- /.links -->
